==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_results/mp2235_001/MP2235_CreateKit_001_Result.java <==

package net.datastream.schemas.mp_results.mp2235_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ResultData">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_fields}DBSESSIONID"/>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP2235_CreateKit_001_Result")
public class MP2235_CreateKit_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected MP2235_CreateKit_001_Result.ResultData resultData;

    /**
     * Gets the value of the resultData property.
     * 
     * @return
     *     possible object is
     *     {@link MP2235_CreateKit_001_Result.ResultData }
     *     
     */
    public MP2235_CreateKit_001_Result.ResultData getResultData() {
        return resultData;
    }

    /**
     * Sets the value of the resultData property.
     * 
     * @param value
     *     allowed object is
     *     {@link MP2235_CreateKit_001_Result.ResultData }
     *     
     */
    public void setResultData(MP2235_CreateKit_001_Result.ResultData value) {
        this.resultData = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DBSESSIONID"/>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "dbsessionid"
    })
    public static class ResultData {

        @XmlElement(name = "DBSESSIONID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
        protected QUANTITY dbsessionid;

        /**
         * Gets the value of the dbsessionid property.
         * 
         * @return
         *     possible object is
         *     {@link QUANTITY }
         *     
         */
        public QUANTITY getDBSESSIONID() {
            return dbsessionid;
        }

        /**
         * Sets the value of the dbsessionid property.
         * 
         * @param value
         *     allowed object is
         *     {@link QUANTITY }
         *     
         */
        public void setDBSESSIONID(QUANTITY value) {
            this.dbsessionid = value;
        }

    }

}

==> eam-wshub-proxyclient-11.5-4-sources.jar: net/datastream/schemas/mp_results/mp2235_001/MP2235_CreateKit_001_Result.java <==

package net.datastream.schemas.mp_results.mp2235_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ResultData">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_fields}DBSESSIONID"/>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP2235_CreateKit_001_Result")
public class MP2235_CreateKit_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected MP2235_CreateKit_001_Result.ResultData resultData;

    /**
     * Obtient la valeur de la propriété resultData.
     * 
     * @return
     *     possible object is
     *     {@link MP2235_CreateKit_001_Result.ResultData }
     *     
     */
    public MP2235_CreateKit_001_Result.ResultData getResultData() {
        return resultData;
    }

    /**
     * Définit la valeur de la propriété resultData.
     * 
     * @param value
     *     allowed object is
     *     {@link MP2235_CreateKit_001_Result.ResultData }
     *     
     */
    public void setResultData(MP2235_CreateKit_001_Result.ResultData value) {
        this.resultData = value;
    }


    /**
     * <p>Classe Java pour anonymous complex type.
     * 
     * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DBSESSIONID"/>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "dbsessionid"
    })
    public static class ResultData {

        @XmlElement(name = "DBSESSIONID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
        protected QUANTITY dbsessionid;

        /**
         * Obtient la valeur de la propriété dbsessionid.
         * 
         * @return
         *     possible object is
         *     {@link QUANTITY }
         *     
         */
        public QUANTITY getDBSESSIONID() {
            return dbsessionid;
        }

        /**
         * Définit la valeur de la propriété dbsessionid.
         * 
         * @param value
         *     allowed object is
         *     {@link QUANTITY }
         *     
         */
        public void setDBSESSIONID(QUANTITY value) {
            this.dbsessionid = value;
        }

    }

}
